# rust-contracts-builder

## installation

```bash
python3 -m pip install rust-contracts-builder
```

## init

```bash
    rust-contract init hello
```

## build

```bash
rust-contract build --stack-size 8192
```

